@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.7.3, released
- *  on Mon Jul 15 11:44:21 UTC 2024
+ *  This file is part of MUMPS 5.8.2, released
+ *  on Mon Jan 12 15:17:08 UTC 2026
  *
  *
- *  Copyright 1991-2024 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2026 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -61,6 +61,10 @@ void LIBSEQ_CALL mumps_checkaddrequal__(char *a, char*b, LIBSEQ_INT8 *i)
  {
    MUMPS_CHECKADDREQUAL(a,b,i);
  }
+void LIBSEQ_CALL mumps_checkaddrequal(char *a, char*b, LIBSEQ_INT8 *i)
+ {
+   MUMPS_CHECKADDREQUAL(a,b,i);
+ }
 
 double LIBSEQ_CALL MPI_Wtime()
 {
